# Copyright 2023 Le Filament (https://le-filament.com)
# License AGPL-3.0 or later (http://www.gnu.org/licenses/agpl.html)

from datetime import date

from dateutil.relativedelta import relativedelta

from odoo import fields, models


class Hall(models.Model):
    _inherit = "hall.hall"

    # ------------------------------------------------------
    # Fields declaration
    # ------------------------------------------------------

    # ------------------------------------------------------
    # SQL Constrains
    # ------------------------------------------------------

    # ------------------------------------------------------
    # Compute functions
    # ------------------------------------------------------

    # ------------------------------------------------------
    # Action buttons
    # ------------------------------------------------------
    def show_planning(self):
        self.ensure_one()
        action = self.env["ir.actions.actions"]._for_xml_id(
            "festa_dashboard.hall_planning_action"
        )
        action["context"] = {
            "active_id": self.id,
            "active_ids": self.ids,
            "search_default_name": self.name,
            "": date.today() - relativedelta(days=1),
        }
        return action

    # ------------------------------------------------------
    # Common functions
    # ------------------------------------------------------
    def get_planning(self, date_filter):
        """
        :param str date_filter: date du calcul du planning
        """
        contract_ids = self.mapped("contract_ids").filtered(
            lambda c: c.is_running(fields.Date.from_string(date_filter))
        )
        sale_ids = self.env["hall.contract.sale.report"].read_group(
            [("contract_id", "in", contract_ids.ids), ("day_date", "=", date_filter)],
            fields=[
                "day_date",
                "slot_id",
                "contract_id",
                "sales_excl_taxes",
                "nb_receipts",
            ],
            groupby=["day_date", "slot_id", "contract_id"],
            lazy=False,
        )
        slot_ids = self.env["hall.day.slot"].search([])
        result = {
            "contract_ids": contract_ids,
            "sale_ids": {
                (s.get("contract_id")[0], s.get("slot_id")[0]): s for s in sale_ids
            },
            "slot_ids": slot_ids,
            "company_id": self.env.company,
        }
        return result
