odoo.define("festa_dashboard.contract_planning", function (require) {
    "use strict";

    const qweb = require("web.qweb");
    const viewRegistry = require("web.view_registry");

    const Controller = qweb.Controller.extend({
        events: _.extend({}, qweb.Controller.prototype.events, {
            "click #previous": "_onClickPrevious",
            "click #next": "_onClickNext",
            "change #change_date": "_onChangeDate",
        }),
        /**
         * @private
         */
        _onClickPrevious: function () {
            const date_filter = this.model._state.context.date_filter;
            let new_date = moment().subtract(2, "days");
            if (date_filter) {
                new_date = moment(date_filter, "YYYY-MM-DD").subtract(2, "days");
            }
            this.update({context: {date_filter: new_date.format("YYYY-MM-DD")}});
        },
        /**
         * @private
         */
        _onClickNext: function () {
            const date_filter = this.model._state.context.date_filter;
            let new_date = moment();
            if (date_filter) {
                new_date = moment(date_filter, "YYYY-MM-DD").add(1, "days");
            }
            this.reload({context: {date_filter: new_date.format("YYYY-MM-DD")}});
        },
        /**
         * @private
         * @param {Event} e
         */
        _onChangeDate: function (e) {
            const new_date = moment(e.target.value, "YYYY-MM-DD");
            this.reload({context: {date_filter: new_date.format("YYYY-MM-DD")}});
        },
    });

    const ContractOverview = qweb.View.extend({
        withSearchBar: true,
        searchMenuTypes: [],
        config: _.extend({}, qweb.View.prototype.config, {
            Controller: Controller,
        }),
    });

    viewRegistry.add("contract_planning", ContractOverview);
});
